<?php

/**
 * Ekomi
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Open Software License (OSL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/osl-3.0.php
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@magentocommerce.com so we can send you a copy immediately.
 *
 * @category    Ekomi
 * @package     Ekomi_EkomiIntegration
 * @copyright   Copyright (c) 2018 Ekomi ltd (http://www.ekomi.de)
 * @license     http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
 *
 * Class Ekomi_EkomiIntegration_Block_PRC
 */
class Ekomi_EkomiIntegration_Block_PRC extends Mage_Core_Block_Template implements Mage_Widget_Block_Interface
{
    const PRODUCT_IDENTIFIER_SKU = 'sku';
    const IDENTIFIER_IDS = 'productIds';
    const IDENTIFIER_SKU = 'productSku';
    const PRODUCT_TYPE_BUNDLE = 'bundle';
    const PRODUCT_TYPE_GROUPED = 'grouped';
    const PRODUCT_TYPE_CONFIGURABLE = 'configurable';

    /**
     * @return bool
     */
    public function isModuleEnabled()
    {
        return $this->getDataHelper()->isModuleEnabled($this->getCurrentStoreId());
    }

    /**
     * @return bool
     */
    public function isPrcEnabled()
    {
        return $this->getDataHelper()->isPrcEnabled($this->getCurrentStoreId());
    }

    /**
     * @return string ID|SKU
     */
    public function getCurrentProductId()
    {
        $productsData = $this->getProductsDataByType(Mage::registry('current_product'));
        $productIdentifier = $this->getDataHelper()->getProductIdentifier($this->getCurrentStoreId());
        if ($productIdentifier == self::PRODUCT_IDENTIFIER_SKU) {
            return implode(',', $productsData[self::IDENTIFIER_SKU]);
        }

        return implode(',', $productsData[self::IDENTIFIER_IDS]);
    }

    /**
     * @param Product $product
     * @return array
     */
    public function getProductsDataByType($product)
    {
        $productsData = array();
        $associatedProducts = array();
        $productsData[self::IDENTIFIER_IDS][] = $product->getId();
        $productsData[self::IDENTIFIER_SKU][] = $product->getSku();

        $productType = $product->getTypeId();
        if ($productType == self::PRODUCT_TYPE_GROUPED) {
            $associatedProducts = $product->getTypeInstance(true)->getAssociatedProducts($product);
        } elseif ($productType == self::PRODUCT_TYPE_BUNDLE) {
            $associatedProducts = $product->getTypeInstance(true)->getSelectionsCollection(
                $product->getTypeInstance(true)->getOptionsIds($product), $product
            );
        } elseif ($productType == self::PRODUCT_TYPE_CONFIGURABLE) {
            $associatedProducts = Mage::getModel('catalog/product_type_configurable')
                ->getUsedProductCollection($product);
        }

        foreach ($associatedProducts as $associatedProduct) {
            $productsData[self::IDENTIFIER_IDS][] = $associatedProduct->getId();
            $productsData[self::IDENTIFIER_SKU][] = $associatedProduct->getSku();
        }

        return $productsData;
    }

    /**
     * @return string ShopId
     */
    public function getShopId()
    {
        return $this->getDataHelper()->getShopId($this->getCurrentStoreId());
    }

    /**
     * @return string WidgetToken
     */
    public function getWidgetToken()
    {
        return $this->getDataHelper()->getWidgetToken($this->getCurrentStoreId());
    }

    /**
     * @return int
     */
    public function getCurrentStoreId()
    {
        $storeId = 0;
        try {
            $storeId = Mage::app()->getStore()->getStoreId();
        } catch (Exception $e) {
            Mage::logException($e);
        }

        return $storeId;
    }

    /**
     * @return Mage_Core_Helper_Abstract
     */
    public function getDataHelper()
    {
        return Mage::helper('ekomi_ekomiIntegration');
    }
}
