<?php

/**
 * Ekomi
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Open Software License (OSL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/osl-3.0.php
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@magentocommerce.com so we can send you a copy immediately.
 *
 * @category    Ekomi
 * @package     Ekomi_EkomiIntegration
 * @copyright   Copyright (c) 2018 Ekomi ltd (http://www.ekomi.de)
 * @license     http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
 *
 * Class Ekomi_EkomiIntegration_Helper_Data
 */
class Ekomi_EkomiIntegration_Helper_Data extends Mage_Core_Helper_Abstract
{
    /**
     * Constants used in class
     */
    const XML_PATH_ACTIVE          = 'ekomitab/ekomi_ekomiIntegration/active';
    const XML_PATH_PRODUCT_REVIEWS = 'ekomitab/ekomi_ekomiIntegration/product_reviews';
    const XML_PATH_SHOP_ID         = 'ekomitab/ekomi_ekomiIntegration/shop_id';
    const XML_PATH_SHOP_PASSWORD   = 'ekomitab/ekomi_ekomiIntegration/shop_password';
    const XML_PATH_ORDER_STATUS    = 'ekomitab/ekomi_ekomiIntegration/order_status';
    const XML_PATH_REVIEW_MOD      = 'ekomitab/ekomi_ekomiIntegration/review_mod';
    const XML_PATH_EXPORT_METHOD   = 'ekomitab/ekomi_ekomiIntegration/export_method';
    const XML_PATH_TURNAROUND_TIME = 'ekomitab/ekomi_ekomiIntegration/turnaround_time';
    const XML_PATH_IDENTIFIER      = 'ekomitab/ekomi_ekomiIntegration/product_identifier';
    const XML_PATH_EXCLUDE_IDS     = 'ekomitab/ekomi_ekomiIntegration/exclude_products';
    const XML_PATH_ACTIVE_PRC      = 'ekomitab/ekomi_ekomiPrc/show_prc';
    const XML_PATH_WIDGET_TOKEN    = 'ekomitab/ekomi_ekomiPrc/widget_token';
    const XML_PATH_TERMS_CONDITION = 'ekomitab/ekomi_ekomiIntegration/terms_condition';

    const PD_API_URL        = 'https://plugins-dashboard.ekomiapps.de/api/v1/country-code';
    const API_RESPONSE_TYPE = 'success';
    const E164_PATTERN      = '/^\+?[1-9]\d{1,14}$/';
    const REVIEW_MODE_EMAIL = 'email';

    /**
     * Checks if module is enabled
     *
     * @param null|int $store
     * @return bool|mixed
     */
    public function isModuleEnabled($store = null)
    {
        return Mage::getStoreConfig(self::XML_PATH_ACTIVE, $store);
    }

    /**
     * Returns Product reviews value
     *
     * @param null|int $store
     * @return mixed
     */
    public function isProductReviewEnabled($store = null)
    {
        return Mage::getStoreConfig(self::XML_PATH_PRODUCT_REVIEWS, $store);
    }

    /**
     * Gets shop id
     *
     * @param null|int $store
     * @return mixed
     */
    public function getShopId($store = null)
    {
        return Mage::getStoreConfig(self::XML_PATH_SHOP_ID, $store);
    }

    /**
     * Gets shop password
     *
     * @param null|int $store
     * @return mixed
     */
    public function getShopPassword($store = null)
    {
        return Mage::getStoreConfig(self::XML_PATH_SHOP_PASSWORD, $store);
    }

    /**
     * Gets terms and conditions value
     *
     * @param null|int $store
     * @return mixed
     */
    public function isTermsAndConditionsAccepted($store = null)
    {
        return Mage::getStoreConfig(self::XML_PATH_TERMS_CONDITION, $store);
    }

    /**
     * Gets order statuses
     *
     * @param null|int $store
     * @return mixed
     */
    public function getOrderStatusForReviewEmail($store = null)
    {
        return Mage::getStoreConfig(self::XML_PATH_ORDER_STATUS, $store);
    }

    /**
     * Gets Review Mode, default will be email if not set
     *
     * @param null|int $store
     * @return mixed
     */
    public function getReviewMod($store = null)
    {
        return Mage::getStoreConfig(self::XML_PATH_REVIEW_MOD, $store)
        ? Mage::getStoreConfig(self::XML_PATH_REVIEW_MOD, $store)
        : self::REVIEW_MODE_EMAIL;
    }

    /**
     * Gets Exports method
     *
     * @param null|int $store
     * @return mixed
     */
    public function getExportMethod($store = null)
    {
        return Mage::getStoreConfig(self::XML_PATH_EXPORT_METHOD, $store);
    }

    /**
     * Gets turnaround time
     *
     * @param null|int $store
     * @return mixed
     */
    public function getTurnaroundTime($store = null)
    {
        return Mage::getStoreConfig(self::XML_PATH_TURNAROUND_TIME, $store);
    }

    /**
     * Gets Product Identifier
     *
     * @param null|int $store
     * @return mixed
     */
    public function getProductIdentifier($store = null)
    {
        return Mage::getStoreConfig(self::XML_PATH_IDENTIFIER, $store);
    }

    /**
     * Gets Exclude Products IDs
     *
     * @param null|int $store
     * @return mixed
     */
    public function getExcludeProducts($store = null)
    {
        return Mage::getStoreConfig(self::XML_PATH_EXCLUDE_IDS, $store);
    }

    /**
     * Checks if PRC widget is enabled
     *
     * @param null|int $store
     * @return mixed
     */
    public function isPrcEnabled($store = null)
    {
        return Mage::getStoreConfig(self::XML_PATH_ACTIVE_PRC, $store);
    }

    /**
     * Gets PRC widget token
     *
     * @param null|int $store
     * @return mixed
     */
    public function getWidgetToken($store = null)
    {
        return Mage::getStoreConfig(self::XML_PATH_WIDGET_TOKEN, $store);
    }

    /**
     * Handles all API requests
     *
     * @param $method
     * @param $apiUrl
     * @param array $headers
     * @param string $body
     * @return bool|string
     */
    public function apiRequest($method, $apiUrl, $headers = array(), $body = '')
    {
        try {
            $curl = new Varien_Http_Adapter_Curl();

            if ($method == Zend_Http_Client::PUT) {
                $curl->setConfig('header', true);
                $curl->addOption(CURLOPT_CUSTOMREQUEST, 'PUT');
                $curl->addOption(CURLOPT_POSTFIELDS, $body);
            }

            $curl->write($method, $apiUrl, Zend_Http_Client::HTTP_1, $headers, $body);
            $data = $curl->read();
            $curl->close();

            if ($data === false) {
                return false;
            }

            return Zend_Http_Response::extractBody($data);
        } catch (Exception $e) {
            Mage::logException($e);
        }
    }
}
