<?php

/**
 * Ekomi
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Open Software License (OSL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/osl-3.0.php
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@magentocommerce.com so we can send you a copy immediately.
 *
 * @category    Ekomi
 * @package     Ekomi_EkomiIntegration
 * @copyright   Copyright (c) 2018 Ekomi ltd (http://www.ekomi.de)
 * @license     http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
 *
 * Class Ekomi_EkomiIntegration_Model_Validate
 */
class Ekomi_EkomiIntegration_Model_Validate extends Mage_Core_Model_Config_Data
{
    /**
     * Constants used in class
     */
    const GET_SETTINGS_API_URL     = 'http://api.ekomi.de/v3/getSettings';
    const ACCESS_DENIED_RESPONSE   = 'Access denied';
    const MARKETPLACE_REVIEW_LINK  = "https://marketplace.magento.com/ekomiltd-ekomi-integration.html";

    /**
     * Saves Post data
     * 
     * @return Mage_Core_Model_Abstract
     * @throws Exception
     * @throws Mage_Core_Exception
     */
    public function save()
    {
        $postData = Mage::app()->getRequest()->getPost();

        foreach ($postData['groups']['ekomi_ekomiIntegration'] as $fields) {
            if ($fields['shop_id'])
                $shopId = $fields['shop_id']['value'];
            if ($fields['shop_password'])
                $shopPassword = $fields['shop_password']['value'];
        }

        $helper = Mage::helper('ekomi_ekomiIntegration');

        if ($shopId == ''
            && isset($postData['groups']['ekomi_ekomiIntegration']['fields']['shop_id']['inherit'])
            && $postData['groups']['ekomi_ekomiIntegration']['fields']['shop_id']['inherit'] == 1
        ) {
            $shopId = $helper->getShopId();
        }

        if ($shopPassword == ''
            && isset($postData['groups']['ekomi_ekomiIntegration']['fields']['shop_password']['inherit'])
            && $postData['groups']['ekomi_ekomiIntegration']['fields']['shop_password']['inherit'] == 1
        ) {
            $shopPassword = $helper->getShopPassword();
        }

        if ($shopId == '' || $shopPassword == '') {
            Mage::throwException('Shop ID & Password Required.');
        } else {
            $serverOutput = $this->verifyAccount($shopId, $shopPassword);
            if ($serverOutput == null || $serverOutput == self::ACCESS_DENIED_RESPONSE) {
                Mage::throwException($serverOutput . ", Invalid Shop ID or Password.");
            } else {
                $response = parent::save();
                $this->addReviewNotification();

                return $response;
            }
        }
    }

    /**
     * Verifies if eKomi credentials are valid
     *
     * @param $shopId
     * @param $shopPw
     * @return string
     */
    public function verifyAccount($shopId, $shopPw)
    {
        $getSettingsUrl  = self::GET_SETTINGS_API_URL . "?auth=" . $shopId . "|" . $shopPw;
        $getSettingsUrl .= "&version=cust-1.0.0&type=request&charset=iso&app=PD-magento-1";
        $helper = Mage::helper('ekomi_ekomiIntegration');

        return $helper->apiRequest(Zend_Http_Client::GET, $getSettingsUrl);
    }

    /**
     * Adds push notification for plugin review on marketplace
     * @return void
     */
    public function addReviewNotification()
    {
        $session = Mage::getSingleton('adminhtml/session');
        $reviewLink = '<a href="' . self::MARKETPLACE_REVIEW_LINK . '" target="_blank">review our plugin</a>';
        $notificationTxt  = 'Your feedback is important. Please take a moment to ' . $reviewLink;
        $session->addSuccess(Mage::helper('adminhtml')->__($notificationTxt));
    }
}
